@@ -18,26 +18,26 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include <kdeversion.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include "btpref.h"
 #include "settings.h"
 
 namespace kt
 {
-	BTPref::BTPref(QWidget* parent): PrefPageInterface(Settings::self(),i18n("BitTorrent"),"application-x-bittorrent",parent)
-	{
-		setupUi(this);
-	}
-	
-	BTPref::~BTPref() 
-	{
-	}
+    BTPref::BTPref(QWidget* parent): PrefPageInterface(Settings::self(), i18n("BitTorrent"), "application-x-bittorrent", parent)
+    {
+        setupUi(this);
+    }
+
+    BTPref::~BTPref()
+    {
+    }
+
+    void BTPref::loadSettings()
+    {
+        kcfg_allowUnencryptedConnections->setEnabled(Settings::useEncryption());
+        kcfg_dhtPort->setEnabled(Settings::dhtSupport());
+        kcfg_customIP->setEnabled(Settings::useCustomIP());
+    }
 
-	void BTPref::loadSettings()
-	{
-		kcfg_allowUnencryptedConnections->setEnabled(Settings::useEncryption());
-		kcfg_dhtPort->setEnabled(Settings::dhtSupport());
-		kcfg_customIP->setEnabled(Settings::useCustomIP());
-	}
-	
 }
