@@ -21,54 +21,56 @@
 #define KTschedulerPLUGIN_H
 
 #include <QTimer>
-#include <KAction>
+#include <QAction>
 #include <interfaces/plugin.h>
 #include <interfaces/guiinterface.h>
 #include "screensaver_interface.h"
 
+
 class QString;
 
 
 namespace kt
-{	
-	class ScheduleEditor;
-	class Schedule;
-	class BWPrefPage;
-	
-	/**
-	 * @author Ivan Vasic <ivasic@gmail.com>
-	 * @brief KTorrent scheduler plugin.
-	 *
-	 */
-	class BWSchedulerPlugin : public Plugin
-	{
-		Q_OBJECT
-	public:
-		BWSchedulerPlugin(QObject* parent, const QStringList& args);
-		virtual ~BWSchedulerPlugin();
+{
+    class ScheduleEditor;
+    class Schedule;
+    class BWPrefPage;
 
-		virtual void load();
-		virtual void unload();
-		virtual bool versionCheck(const QString& version) const;
-		
-	public slots:
-		void timerTriggered();
-		void onLoaded(Schedule* ns);
-		void colorsChanged();
-		void screensaverActivated(bool on);
-		
-	private:
-		void setNormalLimits();
-		void restartTimer();
-		
-	private:
-		QTimer m_timer;
-		ScheduleEditor* m_editor;
-		Schedule* m_schedule;
-		BWPrefPage* m_pref;
-		org::freedesktop::ScreenSaver* screensaver;
-		bool screensaver_on;
-	};
+    /**
+     * @author Ivan Vasic <ivasic@gmail.com>
+     * @brief KTorrent scheduler plugin.
+     *
+     */
+    class BWSchedulerPlugin : public Plugin
+    {
+        Q_OBJECT
+    public:
+        BWSchedulerPlugin(QObject* parent, const QVariantList& args);
+        virtual ~BWSchedulerPlugin();
+
+        virtual void load();
+        virtual void unload();
+        virtual bool versionCheck(const QString& version) const;
+
+    public slots:
+        void timerTriggered();
+        void onLoaded(Schedule* ns);
+        void colorsChanged();
+        void screensaverActivated(bool on);
+        void networkStatusChanged(bool online);
+
+    private:
+        void setNormalLimits();
+        void restartTimer();
+
+    private:
+        QTimer m_timer;
+        ScheduleEditor* m_editor;
+        Schedule* m_schedule;
+        BWPrefPage* m_pref;
+        org::freedesktop::ScreenSaver* screensaver;
+        bool screensaver_on;
+    };
 
 }
 
