@@ -18,58 +18,60 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <klocale.h>
+#include "mediaplayerplugin.h"
+
+#include <klocalizedstring.h>
 #include <kgenericfactory.h>
 #include <util/log.h>
 #include <util/logsystemmanager.h>
 #include <interfaces/guiinterface.h>
-#include "mediaplayerplugin.h"
 #include "mediaplayeractivity.h"
 
 
-K_EXPORT_COMPONENT_FACTORY(ktmediaplayerplugin,KGenericFactory<kt::MediaPlayerPlugin>("ktmediaplayerplugin"))
-		
+K_PLUGIN_FACTORY_WITH_JSON(ktorrent_mediaplayer, "ktorrent_mediaplayer.json", registerPlugin<kt::MediaPlayerPlugin>();)
+
 using namespace bt;
 
 namespace kt
 {
 
-	MediaPlayerPlugin::MediaPlayerPlugin(QObject* parent, const QStringList& args) : Plugin(parent)
-	{
-		Q_UNUSED(args);
-	}
+    MediaPlayerPlugin::MediaPlayerPlugin(QObject* parent, const QVariantList& args) : Plugin(parent)
+    {
+        Q_UNUSED(args);
+    }
+
+
+    MediaPlayerPlugin::~MediaPlayerPlugin()
+    {
+    }
+
+    void MediaPlayerPlugin::load()
+    {
+        LogSystemManager::instance().registerSystem(i18n("Media Player"), SYS_MPL);
+        CoreInterface* core = getCore();
+        act = new MediaPlayerActivity(core, actionCollection(), 0);
+        getGUI()->addActivity(act);
+        setXMLFile("ktorrent_mediaplayerui.rc");
+        act->enableActions(0);
+        act->loadState(KSharedConfig::openConfig());
+    }
+
+    void MediaPlayerPlugin::unload()
+    {
+        LogSystemManager::instance().unregisterSystem(i18n("Media Player"));
+        act->saveState(KSharedConfig::openConfig());
+        act->setVideoFullScreen(false);
+        getGUI()->removeActivity(act);
+        delete act;
+        act = 0;
+    }
+
+    bool MediaPlayerPlugin::versionCheck(const QString& version) const
+    {
+        return version == KT_VERSION_MACRO;
+    }
 
 
-	MediaPlayerPlugin::~MediaPlayerPlugin()
-	{
-	}
-	
-	void MediaPlayerPlugin::load()
-	{
-		LogSystemManager::instance().registerSystem(i18n("Media Player"),SYS_MPL);
-		CoreInterface* core = getCore();
-		act = new MediaPlayerActivity(core,0);
-		act->setupActions(actionCollection());
-		getGUI()->addActivity(act);
-		setXMLFile("ktmediaplayerpluginui.rc");
-		act->enableActions(0);
-		act->loadState(KGlobal::config());
-	}
-	
-	void MediaPlayerPlugin::unload()
-	{
-		LogSystemManager::instance().unregisterSystem(i18n("Media Player"));
-		act->saveState(KGlobal::config());
-		act->setVideoFullScreen(false);
-		getGUI()->removeActivity(act);
-		delete act;
-		act = 0;
-	}
-	
-	bool MediaPlayerPlugin::versionCheck(const QString& version) const
-	{
-		return version == KT_VERSION_MACRO;
-	}
-	
-	
 }
+
+#include "mediaplayerplugin.moc"
