@@ -27,39 +27,40 @@
 namespace kt
 {
 
-	FeedListView::FeedListView(FeedList* feeds,QWidget* parent)
-			: QListView(parent),feeds(feeds)
-	{
-		setContextMenuPolicy(Qt::CustomContextMenu);
-		setSelectionMode(QAbstractItemView::ContiguousSelection);
-		setModel(feeds);
-		setItemDelegate(new FeedListDelegate(this));
-		setAlternatingRowColors(true);
-		setEditTriggers(QAbstractItemView::SelectedClicked|QAbstractItemView::EditKeyPressed);
-		connect(this,SIGNAL(doubleClicked(const QModelIndex &)),this,SLOT(itemActivated(const QModelIndex&)));
-		connect(this->selectionModel(),SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
-				this,SLOT(selectionChanged(const QItemSelection&, const QItemSelection&)));
-	}
+    FeedListView::FeedListView(FeedList* feeds, QWidget* parent)
+        : QListView(parent), feeds(feeds)
+    {
+        setContextMenuPolicy(Qt::CustomContextMenu);
+        setSelectionMode(QAbstractItemView::ExtendedSelection);
+        setModel(feeds);
+        setItemDelegate(new FeedListDelegate(this));
+        setAlternatingRowColors(true);
+        setEditTriggers(QAbstractItemView::SelectedClicked | QAbstractItemView::EditKeyPressed);
+        connect(this, SIGNAL(doubleClicked(const QModelIndex&)), this, SLOT(itemActivated(const QModelIndex&)));
+        connect(this, SIGNAL(clicked(QModelIndex)), this, SLOT(itemActivated(QModelIndex)));
+        connect(this->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
+                this, SLOT(selectionChanged(const QItemSelection&, const QItemSelection&)));
+    }
 
 
-	FeedListView::~FeedListView()
-	{
-	}
+    FeedListView::~FeedListView()
+    {
+    }
 
-	void FeedListView::itemActivated(const QModelIndex & idx)
-	{
-		feedActivated(feeds->feedForIndex(idx));
-	}
+    void FeedListView::itemActivated(const QModelIndex& idx)
+    {
+        feedActivated(feeds->feedForIndex(idx));
+    }
 
-	void FeedListView::selectionChanged(const QItemSelection& sel, const QItemSelection& desel)
-	{
-		Q_UNUSED(desel);
-		Q_UNUSED(sel);
-		enableRemove(selectionModel()->selectedRows().count() > 0);
-	}
-	
-	QModelIndexList FeedListView::selectedFeeds()
-	{
-		return selectionModel()->selectedRows();
-	}
+    void FeedListView::selectionChanged(const QItemSelection& sel, const QItemSelection& desel)
+    {
+        Q_UNUSED(desel);
+        Q_UNUSED(sel);
+        enableRemove(selectionModel()->selectedRows().count() > 0);
+    }
+
+    QModelIndexList FeedListView::selectedFeeds()
+    {
+        return selectionModel()->selectedRows();
+    }
 }
